airignis package
================

Submodules
----------

airignis.autoevent module
-------------------------

.. automodule:: airignis.autoevent
   :members:
   :undoc-members:
   :show-inheritance:

airignis.duetime module
-----------------------

.. automodule:: airignis.duetime
   :members:
   :undoc-members:
   :show-inheritance:

airignis.event module
---------------------

.. automodule:: airignis.event
   :members:
   :undoc-members:
   :show-inheritance:

airignis.exceptions module
--------------------------

.. automodule:: airignis.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: airignis
   :members:
   :undoc-members:
   :show-inheritance:
